'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loginRequest = loginRequest;
exports.jwtLoginRequest = jwtLoginRequest;
exports.loginSuccess = loginSuccess;
exports.loginError = loginError;
exports.logout = logout;
exports.default = rootSaga;

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _effects = require('redux-saga/effects');

var _session = require('../../helpers/session');

var _components = require('../../components');

var _jwtAuthentication = require('../../helpers/jwtAuthentication');

var _jwtAuthentication2 = _interopRequireDefault(_jwtAuthentication);

var _actions = require('./actions');

var _actions2 = _interopRequireDefault(_actions);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _marked = /*#__PURE__*/_regenerator2.default.mark(loginRequest),
    _marked2 = /*#__PURE__*/_regenerator2.default.mark(jwtLoginRequest),
    _marked3 = /*#__PURE__*/_regenerator2.default.mark(loginSuccess),
    _marked4 = /*#__PURE__*/_regenerator2.default.mark(loginError),
    _marked5 = /*#__PURE__*/_regenerator2.default.mark(logout),
    _marked6 = /*#__PURE__*/_regenerator2.default.mark(rootSaga);

var fakeApiCall = true;
function loginRequest() {
  return _regenerator2.default.wrap(function loginRequest$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          _context2.next = 2;
          return (0, _effects.takeEvery)(_actions2.default.LOGIN_REQUEST, /*#__PURE__*/_regenerator2.default.mark(function _callee(_ref) {
            var payload = _ref.payload;
            return _regenerator2.default.wrap(function _callee$(_context) {
              while (1) {
                switch (_context.prev = _context.next) {
                  case 0:
                    if (!fakeApiCall) {
                      _context.next = 5;
                      break;
                    }

                    _context.next = 3;
                    return (0, _effects.put)({
                      type: _actions2.default.LOGIN_SUCCESS,
                      token: 'secret token',
                      profile: 'Profile'
                    });

                  case 3:
                    _context.next = 7;
                    break;

                  case 5:
                    _context.next = 7;
                    return (0, _effects.put)({ type: _actions2.default.LOGIN_ERROR });

                  case 7:
                  case 'end':
                    return _context.stop();
                }
              }
            }, _callee, this);
          }));

        case 2:
        case 'end':
          return _context2.stop();
      }
    }
  }, _marked, this);
}

function jwtLoginRequest() {
  return _regenerator2.default.wrap(function jwtLoginRequest$(_context4) {
    while (1) {
      switch (_context4.prev = _context4.next) {
        case 0:
          _context4.next = 2;
          return (0, _effects.takeEvery)(_actions2.default.JWT_LOGIN_REQUEST, /*#__PURE__*/_regenerator2.default.mark(function _callee2(_ref2) {
            var payload = _ref2.payload;
            var result;
            return _regenerator2.default.wrap(function _callee2$(_context3) {
              while (1) {
                switch (_context3.prev = _context3.next) {
                  case 0:
                    _context3.next = 2;
                    return (0, _effects.call)(_jwtAuthentication2.default.login, payload.userInfo);

                  case 2:
                    result = _context3.sent;

                    if (!result.error) {
                      _context3.next = 9;
                      break;
                    }

                    (0, _components.notification)('error', result.error);
                    _context3.next = 7;
                    return (0, _effects.put)({ type: _actions2.default.LOGIN_ERROR });

                  case 7:
                    _context3.next = 12;
                    break;

                  case 9:
                    payload.history.push('/dashboard');
                    _context3.next = 12;
                    return (0, _effects.put)({
                      type: _actions2.default.LOGIN_SUCCESS,
                      token: result.token,
                      profile: result.profile
                    });

                  case 12:
                  case 'end':
                    return _context3.stop();
                }
              }
            }, _callee2, this);
          }));

        case 2:
        case 'end':
          return _context4.stop();
      }
    }
  }, _marked2, this);
}

function loginSuccess() {
  return _regenerator2.default.wrap(function loginSuccess$(_context6) {
    while (1) {
      switch (_context6.prev = _context6.next) {
        case 0:
          _context6.next = 2;
          return (0, _effects.takeEvery)(_actions2.default.LOGIN_SUCCESS, /*#__PURE__*/_regenerator2.default.mark(function _callee3(payload) {
            return _regenerator2.default.wrap(function _callee3$(_context5) {
              while (1) {
                switch (_context5.prev = _context5.next) {
                  case 0:
                    (0, _session.setCookie)('login_saga', payload.token);
                    _context5.next = 3;
                    return (0, _session.setCookie)('id_token', payload.token);

                  case 3:
                  case 'end':
                    return _context5.stop();
                }
              }
            }, _callee3, this);
          }));

        case 2:
        case 'end':
          return _context6.stop();
      }
    }
  }, _marked3, this);
}

function loginError() {
  return _regenerator2.default.wrap(function loginError$(_context8) {
    while (1) {
      switch (_context8.prev = _context8.next) {
        case 0:
          _context8.next = 2;
          return (0, _effects.takeEvery)(_actions2.default.LOGIN_ERROR, /*#__PURE__*/_regenerator2.default.mark(function _callee4() {
            return _regenerator2.default.wrap(function _callee4$(_context7) {
              while (1) {
                switch (_context7.prev = _context7.next) {
                  case 0:
                  case 'end':
                    return _context7.stop();
                }
              }
            }, _callee4, this);
          }));

        case 2:
        case 'end':
          return _context8.stop();
      }
    }
  }, _marked4, this);
}

function logout() {
  return _regenerator2.default.wrap(function logout$(_context10) {
    while (1) {
      switch (_context10.prev = _context10.next) {
        case 0:
          _context10.next = 2;
          return (0, _effects.takeEvery)(_actions2.default.LOGOUT, /*#__PURE__*/_regenerator2.default.mark(function _callee5() {
            return _regenerator2.default.wrap(function _callee5$(_context9) {
              while (1) {
                switch (_context9.prev = _context9.next) {
                  case 0:
                    (0, _session.removeCookie)('id_token');

                  case 1:
                  case 'end':
                    return _context9.stop();
                }
              }
            }, _callee5, this);
          }));

        case 2:
        case 'end':
          return _context10.stop();
      }
    }
  }, _marked5, this);
}
function rootSaga() {
  return _regenerator2.default.wrap(function rootSaga$(_context11) {
    while (1) {
      switch (_context11.prev = _context11.next) {
        case 0:
          _context11.next = 2;
          return (0, _effects.all)([(0, _effects.fork)(loginRequest), (0, _effects.fork)(jwtLoginRequest), (0, _effects.fork)(loginSuccess), (0, _effects.fork)(loginError), (0, _effects.fork)(logout)]);

        case 2:
        case 'end':
          return _context11.stop();
      }
    }
  }, _marked6, this);
}